"use strict";
/* global describe, it */
var Rsync = require('../rsync');
var harness = require('./_harness');

var assertOutput = require('./_harness').assertOutput;
var assertOutputPattern = require('./_harness').assertOutputPattern;

describe('shorthands', function () {

//# shell /////////////////////////////////////////////////////////////////////////////////////////
  describe('#shell', function () {
    var tests = [
      { title:   'should add rsh option',
        expect:  /--rsh=ssh/,
        command: function () {
          var rsync = new Rsync();
          rsync.shell('ssh');
          return rsync;
        }
      },
      {
        title:   'should escape additional options',
        expect:  /--rsh="ssh -e"/,
        command: function () {
          var rsync = new Rsync();
          rsync.shell('ssh -e');
          return rsync;
        }
      }
    ];

    harness.runCommandTests(tests);
  });

//# delete ////////////////////////////////////////////////////////////////////////////////////////
  describe('#delete', function () {
    var rsync;

    it ('should add delete option', function () {
      rsync = Rsync.build({ source: 'a.txt', destination: 'b.txt' }).delete();
      assertOutput(rsync, 'rsync --delete a.txt b.txt');

      rsync = Rsync.build({ source: 'c.txt', destination: 'd.txt' }).delete(true);
      assertOutput(rsync, 'rsync --delete c.txt d.txt');
    });

    it ('should be able to be unset', function () {
      rsync = Rsync.build({ source: 'a.txt', destination: 'b.txt' })
                    .delete();
      assertOutput(rsync, 'rsync --delete a.txt b.txt');

      rsync.delete(false);
      assertOutput(rsync, 'rsync a.txt b.txt');
    });

    it ('should ignore input', function () {
      rsync = Rsync.build({ source: 'a.txt', destination: 'b.txt' }).delete({});
      harness.assertOutputPattern(rsync, /\s--delete\s/);

      rsync = Rsync.build({ source: 'a.txt', destination: 'b.txt' }).delete('foobarbaz');
      assertOutputPattern(rsync, /\s--delete\s/);
    });
  });

  describe('#progress', function () {});
  describe('#archive', function () {});
  describe('#compress', function () {});
  describe('#recursive', function () {});
  describe('#update', function () {});
  describe('#quiet', function () {});
  describe('#dirs', function () {});
  describe('#links', function () {});
  describe('#dry', function () {});

});
