/* global describe,it */
"use strict";

var assertOutputPattern = require('./_harness').assertOutputPattern;
var Rsync = require('../rsync');

//# sources
describe('sources', function () {
  var rsync;

  it('should not have regular filenames escaped', function () {
      rsync = Rsync.build({
          source:       [ 'some_file.txt' ],
          destination:  'wherever_we_want.txt'
      });
      assertOutputPattern(rsync, /\ssome_file.txt\s/g);
  });

  it('should have spaced filenames escaped', function () {
      rsync = Rsync.build({
          source:       [ 'some file.txt' ],
          destination:  'wherever_we_want.txt'
      });
      assertOutputPattern(rsync, /\ssome\\ file.txt\s/g);
  });

  it('should have quote characters escaped',function () {
      rsync = Rsync.build({
          source:       [ 'a_quoted\'filename\".txt' ],
          destination:  'themoon'
      });
      assertOutputPattern(rsync, / a_quoted\\'filename\\".txt /);
  });

  it('should allow mixed filenames', function () {
      rsync = Rsync.build({
          source: [
             'example file.txt', 'manual.pdf', '\'special_case 1\'.rtf'
          ],
          destination: 'somewhere_else/'
      });
      assertOutputPattern(rsync, / example\\ file.txt manual.pdf \\'special_case\\ 1\\'.rtf/);
  });
});
